aeadcrypto11

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 20, 2025 License: BSD-3-Clause Imports: 7 Imported by: 0

README

crypto11-tinkAEAD

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AEADCrypto11

type AEADCrypto11 struct {
	// contains filtered or unexported fields
}

AEADCrypto11 wraps a PKCS#11-backed AES key for AEAD encryption/decryption.

func NewAEADCrypto11

func NewAEADCrypto11(ctx *crypto11.Context, keyLabel string) (*AEADCrypto11, error)

NewAEADCrypto11 creates an AEAD using a PKCS#11-backed AES key label.

func (*AEADCrypto11) Decrypt

func (a *AEADCrypto11) Decrypt(ciphertext, associatedData []byte) ([]byte, error)

Decrypt decrypts ciphertext with associated data using the HSM-backed key.

func (*AEADCrypto11) Encrypt

func (a *AEADCrypto11) Encrypt(plaintext, associatedData []byte) ([]byte, error)

Encrypt encrypts plaintext with associated data using the HSM-backed key.

Jump to